##-------------------------------------------------------------------------
##  File:
##	$Id: config.sh.dist,v 1.19 2003/08/09 18:04:08 ehood Exp $
##  Description:
##	This is the main configuration file for the web mail archiving
##	system.  The syntax of this file follows a subset of the Bourne
##	shell syntax.  The reason for the simplicity is so the Perl
##	program can easily parse this file.  The shell scripts can
##	just source this file directly.
##
##	Normal environment variables can be referenced when defining
##	the value of a variable.
##-------------------------------------------------------------------------

##-------------------------------------------------------------------------
##  Main variables to verify
##-------------------------------------------------------------------------

# The SW_ROOT setting is the most important since other variables are
# based upon it.  It should be the pathname to the directory you installed
# mharc.
SW_ROOT=/home/mharc

# MHonArc library path: If MHonArc libraries are not in Perl's default
# search path, add it here.
MHONARC_LIB=/usr/share/mhonarc

# Pathname to source mail spool file: Modify to reflect you system.
# The reference to LOGNAME is an environment variable normally defined
# by the system to represent the username.
#
#   NOTE: If your environment does not define LOGNAME, make sure
#	  to replace the variable with an appropriate value.
#
ORGMAIL=/var/spool/mail/$LOGNAME

# Set to 1 if $ORGMAIL is pathname to a mail spool file.  Else set
# to 0.  This affects how locking is done in filter-spool
IS_MAIL_SPOOL=1

# Root URL to mail archives.  This variable should represent what
# root URL path will be for web browsers to access your archives.
# The *_URL variables below are, by default, based upon this variable.
#
#   NOTE: For portability, it is best to exclude the server name
#	  portion of the URL and only the path component.
#
ROOT_URL=/archive

# Email address of administrator: Used in MKNMZ_RC.
ADMIN_ADDRESS=sysadmin@gnu.org

##-------------------------------------------------------------------------
##  The variables after here can generally be left as-is, but you may
##  want to to check if you want more granular customization.
##-------------------------------------------------------------------------

# Pathname to lists.def.
LISTS_DEF_FILE=$SW_ROOT/lib/lists.def

# Pathname of procmailrc (generated from $LISTS_DEF_FILE)
PROCMAILRC=$SW_ROOT/procmailrc.mharc

# Pathname of directory containing logs
LOG_DIR=$SW_ROOT/log

# Pathname of directory containing CGI programs
CGI_DIR=$SW_ROOT/cgi-bin

# Pathname of directory containing raw mail archives.
MBOX_DIR=$SW_ROOT/mbox

# Pathname of directory containing HTML mail archives.
HTML_DIR=$SW_ROOT/html

# Directory containing informational pages about each list archive.
INFO_DIR=$SW_ROOT/info

# Pathname to directory containing list-specific MHonArc resource files.
MHA_RC_DIR=$SW_ROOT/lib/mrc

# Pathname to main MHonArc resource file.
MHA_RC=$SW_ROOT/lib/common.mrc

# Pathname of archive lists index page.  This page provides a list
# of all archives available.
ALL_LISTS_FILE=$HTML_DIR/index.html

# Pathname of header template for archive lists index page.  The
# header template defines the markup that should occur before the
# all archive listing.
ALL_LISTS_HEADER=$HTML_DIR/.PNM.all-head

# Pathname of footer template for archive lists index page.  The
# footer template defines the markup that should occur after the
# all archive listing.
ALL_LISTS_FOOTER=$HTML_DIR/.PNM.all-foot

# Text label HTML strings for all-lists table.  These can be changed
# to fit a particular locale
ALL_LISTS_LABEL_NAME='Name'
ALL_LISTS_LABEL_INDEXES='Current&nbsp;Index'
ALL_LISTS_LABEL_LAST_UPDATED='Last&nbsp;Updated'
ALL_LISTS_LABEL_INFO='[info]'
ALL_LISTS_LABEL_DATE='[Date]'
ALL_LISTS_LABEL_THREADS='[Thread]'

# The date/time format for showing the Last Updated time of archives
# on all-lists page.  The format is what is supported by strftime.
ALL_LISTS_DATE_FORMAT='%Y-%m-%d %H:%M:%S %z'

# Pathname of header template for period index pages.
MAIN_HEADER=$HTML_DIR/.PNM.head

# Pathname of footer template for period index pages.
MAIN_FOOTER=$HTML_DIR/.PNM.foot

# SEARCH_CGI url should not have to be changed, but the namazu.cgi
# program will need to be copied to $SW_ROOT/cgi-bin directory.
SEARCH_CGI=$ROOT_URL/cgi-bin/namazu.cgi

# URL to mbox archives.  This should be a URL that would access the
# the filesystem location defined by MBOX_DIR.
MBOX_URL=$ROOT_URL/mbox

# URL to html archives.  This should be a URL that would access the
# the filesystem location defined by HTML_DIR.
HTML_URL=$ROOT_URL/html

# Base URL containing informational pages about each list archive.
# This should be a URL that would access the the filesystem location
# defined by INFO_DIR.
INFO_URL=$ROOT_URL/info

# URL providing list of all archives.  This URL would provide the
# user a listing of all the archives available.
ALL_LISTS_URL=$HTML_URL

# URL to CGI programs This should be a URL that would access the the
# filesystem location defined by CGI_DIR.
CGI_URL=$ROOT_URL/cgi-bin

# URL to period navigation CGI program
MNAV_CGI=$CGI_URL/mnav.cgi

# URL to raw message extraction CGI program
EXTRACT_CGI=$CGI_URL/extract-mesg.cgi

# URL to persistent message reference CGI program
MESG_CGI=$CGI_URL/mesg.cgi

# Pathname to procmail program.  If procmail is not in your normal
# search path, change this to the absolate pathname to the program.
PROCMAIL=/usr/bin/procmail

# Procmail search path for $PROCMAILRC.
PROCMAIL_PATH=$SW_ROOT/bin:/usr/local/bin:/bin:/usr/bin

# Pathname to formail program.  If formail is not in your normal
# search path, change this to the absolate pathname to the program.
FORMAIL=/usr/bin/formail

# Pathname to lockfile program.  If lockfile is not in your normal
# search path, change this to the absolate pathname to the program.
LOCKFILE=/usr/bin/lockfile

# Pathname to mknmz program.  If mknmz is not in your normal
# search path, change this to the absolate pathname to the program.
MKNMZ=/usr/bin/mknmz

# Pathname to resource file for mknmz
MKNMZ_RC=$SW_ROOT/cgi-bin/mknmzrc

# Directory containing templates for namazu
MKNMZ_TMPL_DIR=$SW_ROOT/cgi-bin/template

# Lock time out in seconds when processing $ORGMAIL: If the lock
# is older than specified time, then the lock will be removed by
# force.
#ORGMAIL_LOCK_TIMEOUT=3600

# Options to procmail: Uncomment and change as needed if you want
# define extra procmail variables
#PROCMAILVARS="VERBOSE=yes LOGABSTRACT=yes"

# Address to receive all unmatched messages.  If this variable
# is defined, the "catch" archive will be disabled and all
# messages that do not match an archive will be forward to $CATCH_ADDRESS.
#CATCH_ADDRESS=

# Name of the "catch" archive: Uncomment and change to desired
# value.  Note, value should start with a "." for searching to
# be automatically disabled.
#CATCH_ARCHIVE=.catch

# Disable catch archive: Uncomment and change value to 1 if you
# do not want a catch archive.  If CATCH_ADDRESS is defined, this
# variable has no effect.  However, if CATCH_ADDRESS is blank and
# you disable the catch archive, all unmatched messages will be quietly
# dropped.
#DISABLE_CATCH_ARCHIVE=0

# Age of mailbox file, in seconds, to be considered for processing:
# This value should have a value which properly reflects how often
# mail is processed.  Here, 86400 = 1 day.  Since the default template
# crontab settings have mail processed hourly, this should be a
# reasonable setting.  However, if you decrease the frequency of mail
# processing, you may need to increase MTIME_AGE.
MTIME_AGE=86400

# Maximum size, in bytes, of msgid cache for detecting duplicate
# messages.  The larger of volume of messages you process, that
# larger the cache size should be.  The default size of 16K will
# roughly cache that last 300 messages-ids.
#MSGID_CACHE_SIZE=16384

# Destination mailbox for final rule in $PROCMAILRC.
# It is OKAY for this to be /dev/null.  See mk-procmailrc manpage
# for more information.
#FINAL_MSG_DESTINATION=/dev/null

# Message header fields to determine date of a message.  Format same
# as the DATEFIELDS resource of MHonArc.  This variable is used
# be extract-mesg-date and is passed into MHonArc via the DATEFIELDS
# resource.
#MSG_DATE_FIELDS='received:delivery-date:date'

FSF_DOMAIN=lists.gnu.org
